library(ggrepel)
library(ggplot2)
library(ggthemes)
library(gridExtra)
library(dplyr)
library(reshape2)
library(igraph)
#setwd("/localpath")
TT <- read.csv("Trend_Topics_MinFreq8_ALL960.csv", header=T)
SC <- read.csv("Word_Dynamics_SCcombined_byrow.csv", header=T)
SC <- SC[(SC$year > 2011) & (SC$year<2021),]
SC <- SC %>% 
  mutate(label = ifelse(year == max(year), as.character(item), NA)) 

p1 <- ggplot(TT, aes(x=year, y=log_freq, label = item)) +
  geom_point(color = "gray50") +
  geom_label_repel(aes(size = 10, family = "serif", fontface = "bold", fill =  factor(sector)),
                       #color = ifelse(sector == 1, "green", "red")),
                   segment.color = 'gray50',
                   box.padding = 0.5,size = 4,label.size = NA) +
  theme_classic() + 
  labs(x = "")+
  theme(legend.position="none",text=element_text(family = "serif"))


p2 <- ggplot(SC, aes(x=year, y=freq, group=item, color=item)) +
  geom_line(lwd=1.1) +
  geom_label_repel(aes(label = label, size = 10, family = "serif", fontface = "bold"),
                   nudge_x = 1,na.rm = TRUE, direction = "both", 
                   #segment.color = 'transparent', 
                   box.padding = 0.1,label.size=0.1, size = 4,
                   fill = ifelse(SC$item == "SmartCt", "white", 
                                  ifelse(SC$item == "EnergyEff", "white", 
                                         ifelse(SC$item == 'Sustainability', "gray65", "gray88")))) +
  theme_classic() +
  theme(legend.position="none",text=element_text(family = "serif")) 
  

grid.arrange(p1, p2, nrow = 2)



############################################## Fig 3 Annual scientific production ##############################################
ALLfig3 <- read.csv("Annual_Production_fig3.csv", header=T)
fig3_wo2021 <- ALLfig3[-nrow(ALLfig3-1),]

p3 <- ggplot(data=fig3_wo2021, aes(x=Year, y=Articles, group=1)) +
  geom_line(color="gray", size=1)+
  ylab("Number of Articles") +
  geom_text(aes(label = Articles), nudge_y = 10, family = "serif", fontface = "bold")+
  #geom_label_repel(aes(label = Articles),label.size=NA, nudge_x = 0, nudge_y = 0.5, fill = "transparent")+
  geom_point()+
  theme_classic()+
  theme(legend.position="none",text=element_text(family = "serif")) 
  
#################################################################################################################################
Colnet <- read.csv("Collaboration_Network.csv", header=T)
source <- read.csv("Source_Impact_top20.csv", header=T)
source <- source[1:10,]  #plot only top10 sources

p4 <- ggplot(data = source, aes(x=reorder(Source,h_index), y=h_index)) + 
  geom_bar(stat="identity") + 
  coord_flip() +
  #labs(title="" ) + 
  xlab("Source") +
  geom_text(aes(label = paste("TC =",TC),family = "serif", fontface = "bold"), nudge_y = 1, color="black", size=4, check_overlap = T) +
  geom_text(aes(label = paste("NP =",NP),family = "serif", fontface = "bold"), nudge_y = -2, color="white", size=4, check_overlap = T) +
  theme_classic()   +
  theme(text=element_text(family = "serif"),  axis.text.x = element_text(size=10), axis.text.y = element_text(angle = 0, size=8) ) 
  

grid.arrange(p3, p4, nrow = 2)





